Learn R Programming

MKinfer (version 1.4)

dgt: A Generalized Central t Distribution

Description

Density, distribution function and quantile function for the generalized central t distribution defined in Section 5.3 of Xiao (2018)).

Usage

dgt(x, n1, n2, v1tov2, log = FALSE, MAX = 1e4)
pgt(q, n1, n2, v1tov2, lower.tail = TRUE, log.p = FALSE, 
    rel.tol = .Machine$double.eps^0.25, parallel = FALSE, cl = NULL)
qgt(p, n1, n2, v1tov2, lower.tail = TRUE, log.p = FALSE, 
    tol = .Machine$double.eps^0.5, parallel = FALSE, cl = NULL)

Value

dgt gives the density,

pgt gives the distribution function, and

qgt gives the quantile function

Arguments

x, q

vector of quantiles.

p

vector of probabilities.

n1

sample size of first group.

n2

sample size of second group.

v1tov2

ratio of variances (var1/var2).

log, log.p

logical; if TRUE, probabilities p are given as log(p).

lower.tail

logical; if TRUE (default), probabilities are \(P[X \le x]\), otherwise, \(P[X > x]\).

MAX

maximum number of iterations to determine the hypergeometric function; see function hypergeo.

rel.tol

relative accuracy of integrate.

tol

the desired accuracy (convergence tolerance) of uniroot.

parallel

logical; use parellel computing via function parRapply.

cl

a cluster object, created by package parallel or by package snow. If NULL, a new cluster will be generated with function makeCluster using the maximum number of available cores - 1.

Details

It is possible to provide arguments of length larger than 1 to the functions.

The density of the distribution can be found on page 58 of Xiao (2018). If the hypergeometric function does not converge, one can try to increase the value of MAX.

The distribution function is determined by numerical intergration via function integrate.

The quantile function is determined by applying function uniroot.

References

Y. Xiao (2018). On the Solution of a Generalized Behrens-Fisher Problem. Far East Journal of Theoretical Statistics, 54 (1), 21-140.

See Also