Density, distribution function and quantile function for the generalized central t distribution defined in Section 5.3 of Xiao (2018)).
dgt(x, n1, n2, v1tov2, log = FALSE, MAX = 1e4)
pgt(q, n1, n2, v1tov2, lower.tail = TRUE, log.p = FALSE,
rel.tol = .Machine$double.eps^0.25, parallel = FALSE, cl = NULL)
qgt(p, n1, n2, v1tov2, lower.tail = TRUE, log.p = FALSE,
tol = .Machine$double.eps^0.5, parallel = FALSE, cl = NULL)dgt gives the density,
pgt gives the distribution function, and
qgt gives the quantile function
vector of quantiles.
vector of probabilities.
sample size of first group.
sample size of second group.
ratio of variances (var1/var2).
logical; if TRUE, probabilities p are given as log(p).
logical; if TRUE (default), probabilities are \(P[X \le x]\), otherwise, \(P[X > x]\).
maximum number of iterations to determine the hypergeometric function; see
function hypergeo.
relative accuracy of integrate.
the desired accuracy (convergence tolerance) of uniroot.
logical; use parellel computing via function parRapply.
a cluster object, created by package parallel
or by package snow. If NULL, a new cluster
will be generated with function makeCluster
using the maximum number of available cores - 1.
It is possible to provide arguments of length larger than 1 to the functions.
The density of the distribution can be found on page 58 of Xiao (2018). If the
hypergeometric function does not converge, one can try to increase the value
of MAX.
The distribution function is determined by numerical intergration via function
integrate.
The quantile function is determined by applying function uniroot.
Y. Xiao (2018). On the Solution of a Generalized Behrens-Fisher Problem. Far East Journal of Theoretical Statistics, 54 (1), 21-140.